GNU Health : The Free / Libre Health and Hospital Information System
====================================================================
 
GNU HEALTH is a Free / Libre, Health and Hospital Information System
that provides the following functionality:

#. **Hospital Information System (HIS)**
#. **Electronic Medical Record (EMR)**
#. **Laboratory Information System (LIS)**
#. **Health Information System**

The **GNU Health Federation** allows to interconnect heterogeneous nodes
and build large distributed federated, health networks across a region, 
province or country.


Download
--------

https://www.gnuhealth.org


Documentation
-------------

Wikibooks: https://en.wikibooks.org/wiki/GNU_Health


Support GNU Solidario
---------------------

GNU Health is a project of GNU Solidario. GNU Solidario is an Non-profit
Non-goverment-Organization (NGO) that works globally, delivering health
and education with free software.

Health and education are the basis for the development and dignity of societies. 

You can *become a member* of GNU Solidario and help us deliver Freedom and Equity
in Healthcare around the World.

https://www.gnuhealth.org/donate

GNU Solidario hosts IWEEE and GnuHealthCon:

The International Workshop on e-Health in Emerging Economies- a good way to
support GNU Solidario and to get the latest on e-Health is to assist
to the conferences. 


Need help to implement GNU Health ? 
-----------------------------------

We are committed to do our best in helping out projects that can improve
the health of your country or region. We want the project to be a success,
and since our resources are limited, we need to work together to make a great
and sustainable project.

In order to be elegible, we need the following information from you,
your NGO or government:

    * An introduction of the current needs
    * The project will use free software, both at the server and workstations
    * There will be a local designated person that will be in charge of
        the project and the know-how transfer to the rest of the community.
        This person must be committed to be from the beginning of the
        project until two years after its completion.
    * There must be a commitment of knowledge transfer to the rest of the team.

We will do our best to help you out with the implementation and training
for the local team, to build local capacity and make your project sustainable.

Please send us a mail with that info to info@gnuhealth.org and
we'll back to you as soon as possible.



Thank you !
Luis Falcón, MD
Author and project leader
falcon@gnuhealth.org


Main links
----------
https://www.gnuhealth.org
info@gnuhealth.org

Twitter: @gnuhealth

License:
--------
GNU Health is licensed under GPL v3+

Copyright (C) 2008-2022 Luis Falcon <falcon@gnuhealth.org>
Copyright (C) 2011-2022 GNU Solidario <health@gnusolidario.org>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
